@@ -914,6 +914,14 @@ function install_manila_tempest_plugin {
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
+
+        if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
+            # The public network was created by us, so set it explicitly in
+            # tempest.conf
+            public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
+            iniset $TEMPEST_CONFIG network public_network_id $public_net_id
+        fi
+
         TEMPEST_CONFIG=${TEMPEST_CONFIG:-$TEMPEST_DIR/etc/tempest.conf}
         ADMIN_TENANT_NAME=${ADMIN_TENANT_NAME:-"admin"}
         ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
@@ -1008,6 +1016,24 @@ function install_libraries {
     fi
 }
 
+function allow_host_ports_for_share_mounting {
+
+    TCP_PORTS=(2049 111 32803 892 875 662)
+    UDP_PORTS=(111 32769 892 875 662)
+    for ipcmd in iptables ip6tables; do
+        # (aovchinnikov): extra rules are needed to allow instances talk to
+        # host.
+        sudo $ipcmd -N manila-nfs
+        sudo $ipcmd -I INPUT 1 -j manila-nfs
+        for port in ${TCP_PORTS[*]}; do
+            sudo $ipcmd -A manila-nfs -m tcp -p tcp --dport $port -j ACCEPT
+        done
+        for port in ${UDP_PORTS[*]}; do
+            sudo $ipcmd -A manila-nfs -m udp -p udp --dport $port -j ACCEPT
+        done
+    done
+}
+
 function setup_ipv6 {
 
     # This will fail with multiple default routes and is not needed in CI
@@ -1151,6 +1177,14 @@ function setup_ipv6 {
 
 }
 
+function setup_bgp_for_ipv6 {
+    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
+    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
+    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
+    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
+    neutron bgp-speaker-peer-add bgpspeaker bgppeer
+}
+
 # Main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing Manila Client"
@@ -1262,6 +1296,19 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
 
     echo_summary "Update Tempest config"
     update_tempest
+
+
+    if [[ "$(trueorfalse False MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST)" == "True" ]]; then
+        echo_summary "Allowing IPv4 and IPv6 access to NAS ports on the host"
+        allow_host_ports_for_share_mounting
+    fi
+
+    if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
+        # Now that all plugins are loaded, setup BGP
+        echo_summary "Setting up BGP speaker to advertise routes to project networks"
+        setup_bgp_for_ipv6
+    fi
+
 fi
 
 if [[ "$1" == "unstack" ]]; then
